<?php

declare(strict_types = 1);

namespace Drupal\entity_editor_tabs\Plugin\Menu\LocalTask;

use Drupal\Core\Menu\LocalTaskDefault;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\entity_editor_tabs\EetUtility;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides a local task with customization when layout builder is enabled.
 */
class EetUpdateLocalTask extends LocalTaskDefault implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;
  use EetLocalTaskTrait;

  /**
   * Utility for Entity Editor Tabs.
   *
   * @var \Drupal\entity_editor_tabs\EetUtility
   */
  protected EetUtility $eetUtility;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->stringTranslation = $container->get('string_translation');
    $instance->routeMatch = $container->get('current_route_match');
    $instance->contextRepository = $container->get('context.repository');
    $instance->entityRouteHelper = $container->get('entity_route_context.route_helper');
    $instance->eetUtility = $container->get('entity_editor_tabs.utility');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getTitle(Request $request = NULL) {
    $entity = $this->getEntity();
    if (!$entity) {
      return parent::getTitle($request);
    }

    if (!$this->eetUtility->isLayoutBuilderOverridable($entity->getEntityTypeId(), $entity->bundle())) {
      return parent::getTitle($request);
    }

    return $this->t('Edit metadata', [], [
      'context' => 'layout_builder_overridable',
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags(): array {
    $entity = $this->getEntity();
    return array_merge(
      parent::getCacheTags(),
      ($entity ? $entity->getCacheTags() : []),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts(): array {
    $contexts = parent::getCacheContexts();
    $contexts[] = 'route';
    return $contexts;
  }

}
