<?php

declare(strict_types = 1);

namespace Drupal\Tests\entity_editor_tabs\Functional;

use Drupal\entity_test\Entity\EntityTestMulRevPub;
use Drupal\layout_builder\Entity\LayoutBuilderEntityViewDisplay;
use Drupal\Tests\BrowserTestBase;
use Drupal\user\UserInterface;

/**
 * Tests Layout Builder integrations with Entity Editor Tabs.
 *
 * @group entity_editor_tabs
 */
final class EetLayoutBuilderTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_editor_tabs_test',
    'entity_editor_tabs',
    'entity_test',
    'block',
    'layout_builder',
    'node',
  ];

  /**
   * User for testing.
   *
   * @var \Drupal\user\UserInterface
   */
  protected UserInterface $testUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalPlaceBlock('local_tasks_block');
    $this->testUser = $this->drupalCreateUser([
      'view test entity',
      'administer entity_test content',
      'configure any layout',
    ]);
  }

  /**
   * Tests tabs are customised.
   */
  public function testLayoutBuilderTabs(): void {
    $display = LayoutBuilderEntityViewDisplay::create([
      'targetEntityType' => 'entity_test_mulrevpub',
      'bundle' => 'entity_test_mulrevpub',
      'mode' => 'default',
      'status' => TRUE,
    ]);
    $display
      ->enableLayoutBuilder()
      ->setOverridable()
      ->save();

    $this->drupalLogin($this->testUser);

    $entity = EntityTestMulRevPub::create([
      'name' => $this->randomMachineName(),
      'user_id' => $this->testUser,
    ]);
    $entity->save();

    $this->drupalGet($entity->toUrl());
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->linkExists('View');
    $this->assertSession()->linkExists('Edit metadata');
    $this->assertSession()->linkExists('Edit content');
  }

}
